==> Texture-Font-Generator-2020-Squirrel-buildv0.1.tar.gz: Texture-Font-Generator-2020-Squirrel-buildv0.1/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Visual C++ generated include file.
// Used by Texture Font Generator.rc
//

// For details, see Texture Font GeneratorDlg.cpp
//#define _TFG_JAPANESE_SUPPLEMENTAL
//#define _TFG_CHINESE_ADDITION
 #define _TFG_KOREAN_ADDITION
//#define _TFG_EURO_ADDITION

// DO NOT UNCOMMENT UNTIL STEPMANIA SUPPORTS OVER U+FFFF
#define _TFG_GENERATE_SIP

#define IDP_OLE_INIT_FAILED             100
#define ID_STYLE_ITALIC                 101
#define IDD_TEXTUREFONTGENERATOR_DIALOG 102
#define IDR_MAINFRAME                   103
#define IDR_MENU                        104
#define ID_STYLE_BOLD                   110
#define ID_FILE_SAVE141                 141
#define ID_FILE_EXIT                    142
#define ID_Menu                         143
#define IDR_ACCELERATOR                 144
#define ID_STYLE_ANTIALIASED            302
#define IDC_PICTURE                     1000
#define IDC_SHOWN_PAGE                  1011
#define IDC_FAMILY_LIST                 1013
#define IDC_BOLD                        1015
#define IDC_ITALIC                      1016
#define IDC_TEXT_OVERLAP                1017
#define IDC_FONT_SIZE                   1018
#define IDC_ERROR_OR_WARNING            1020
#define IDC_CLOSEUP                     1021
#define IDC_SPIN_TOP                    1022
#define IDC_SPIN_BASELINE               1023
#define IDC_PADDING                     1025
#define IDC_CHECK1                      1026
#define ID_ACCELERATOR_ITALIC           32773
#define ID_ACCELERATOR_BOLD             32774
#define ID_OPTIONS_DOUBLERESOLUTION     32779
#define ID_OPTIONS_DOUBLERES            32780
#define IDC_OPTIONS_DOUBLERES           32781
#define ID_OPTIONS_EXPORTSTROKETEMPLATES 32782
#define ID_OPTIONS_NUMBERSONLY          32783

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        145
#define _APS_NEXT_COMMAND_VALUE         32784
#define _APS_NEXT_CONTROL_VALUE         1028
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif

==> Texture-Font-Generator-2020-Squirrel-buildv0.32.tar.gz: Texture-Font-Generator-2020-Squirrel-buildv0.32/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Visual C++ generated include file.
// Used by Texture Font Generator.rc
//

// For details, see Texture Font GeneratorDlg.cpp
//#define _TFG_JAPANESE_ADDITION
//#define _TFG_JAPANESE_SUPPLEMENTAL
//#define _TFG_CHINESE_ADDITION
//#define _TFG_KOREAN_ADDITION
#define _TFG_EURO_ADDITION
//#define _TFG_LEGACY_ADDITION


// DO NOT UNCOMMENT UNTIL STEPMANIA SUPPORTS OVER U+FFFF
#define _TFG_GENERATE_SIP

#define IDP_OLE_INIT_FAILED             100
#define ID_STYLE_ITALIC                 101
#define IDD_TEXTUREFONTGENERATOR_DIALOG 102
#define IDR_MAINFRAME                   103
#define IDR_MENU                        104
#define ID_STYLE_BOLD                   110
#define ID_FILE_SAVE141                 141
#define ID_FILE_EXIT                    142
#define ID_Menu                         143
#define IDR_ACCELERATOR                 144
#define ID_STYLE_ANTIALIASED            302
#define IDC_PICTURE                     1000
#define IDC_SHOWN_PAGE                  1011
#define IDC_FAMILY_LIST                 1013
#define IDC_BOLD                        1015
#define IDC_ITALIC                      1016
#define IDC_TEXT_OVERLAP                1017
#define IDC_FONT_SIZE                   1018
#define IDC_ERROR_OR_WARNING            1020
#define IDC_CLOSEUP                     1021
#define IDC_SPIN_TOP                    1022
#define IDC_SPIN_BASELINE               1023
#define IDC_PADDING                     1025
#define IDC_CHECK1                      1026
#define ID_ACCELERATOR_ITALIC           32773
#define ID_ACCELERATOR_BOLD             32774
#define ID_OPTIONS_DOUBLERESOLUTION     32779
#define ID_OPTIONS_DOUBLERES            32780
#define IDC_OPTIONS_DOUBLERES           32781
#define ID_OPTIONS_EXPORTSTROKETEMPLATES 32782
#define ID_OPTIONS_NUMBERSONLY          32783

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        145
#define _APS_NEXT_COMMAND_VALUE         32784
#define _APS_NEXT_CONTROL_VALUE         1028
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif
